from __future__ import division, absolute_import, print_function

from numpy.distutils.fcompiler import FCompiler

compilers = ['ARMHPCFCompiler']

class ARMHPCFCompiler(FCompiler):

    compiler_type = 'armflang'
    description = 'Arm HPC Fortran Compiler'
    version_pattern =  r'Arm C/C\+\+/Fortran Compiler version (?P<version>[\d.]+)'

    executables = {
        'version_cmd'  : ["armflang", "--version"],
        'compiler_f77' : ["armflang", "-Mfixed"],
        'compiler_fix' : ["armflang", "-Mfixed"],
        'compiler_f90' : ["armflang"],
        'linker_so'    : ["armflang", "-shared"],
        'archiver'     : ["ar", "-cr"],
        'ranlib'       : ["ranlib"]
    }
    pic_flags = ['-fPIC -DPIC']
    module_dir_switch = None
    module_include_switch = '-I'

    def get_flags_opt(self):
        return ['-O2']
    def get_flags_debug(self):
        return ['-g']
    def runtime_library_dir_option(self, dir):
        return '-Wl,-rpath="%s"' % dir

if __name__ == '__main__':
    from distutils import log
    log.set_verbosity(2)
    from numpy.distutils.fcompiler import new_fcompiler
    compiler = new_fcompiler(compiler='armflang')
    compiler.customize()
    print(compiler.get_version())
