from __future__ import division, absolute_import, print_function

from numpy.distutils.fcompiler import FCompiler

compilers = ['LLVMFCompiler']

class LLVMFCompiler(FCompiler):

    compiler_type = 'flang'
    description = 'LLVM Fortran Compiler'
    version_pattern =  r'clang version (?P<version>[\d.]+)'

    executables = {
        'version_cmd'  : ["flang", "--version"],
        'compiler_f77' : ["flang", "-Mfixed"],
        'compiler_fix' : ["flang", "-Mfixed"],
        'compiler_f90' : ["flang"],
        'linker_so'    : ["flang", "-shared"],
        'archiver'     : ["ar", "-cr"],
        'ranlib'       : ["ranlib"]
    }
    pic_flags = ['-fPIC -DPIC']
    module_dir_switch = None
    module_include_switch = '-I'

    def get_flags_opt(self):
        return ['-O2']
    def get_flags_debug(self):
        return ['-g']
    def runtime_library_dir_option(self, dir):
        return '-Wl,-rpath="%s"' % dir

if __name__ == '__main__':
    from distutils import log
    log.set_verbosity(2)
    from numpy.distutils.fcompiler import new_fcompiler
    compiler = new_fcompiler(compiler='flang')
    compiler.customize()
    print(compiler.get_version())
